plist

Enum Error

pub enum Error {
Show 18 variants InvalidMagicBytes, InvalidTrailer, VersionNotSupported(Option<String>), InvalidKeyObject, InvalidBoolean, InvalidIntegerSize, ObjectNotSupported(u8), UnexpectedXmlEof, UnexpectedXmlEvent(XmlEvent), XmlObjectNotSupported(String), XmlError(Error), IoError(Error), IntError(ParseIntError), FloatError(ParseFloatError), DateError(ParseError), Base64Error(FromBase64Error), Utf8Error(Utf8Error), Utf16Error(FromUtf16Error),
}
The errors that can occur when parsing a property list.

Variants



InvalidMagicBytes

The binary property list does not have valid magic bytes.



InvalidTrailer

The binary property list trailer does not contain valid values.



VersionNotSupported(Option<String>)

The binary property list does not have a valid version. The only valid version is currently “00”.



InvalidKeyObject

The binary property list has a key object that is not a string.



InvalidBoolean

The binary property list has an invalid nibble for a boolean.



InvalidIntegerSize

The binary property list has an unsupported integer size for an offset, length, or count integer. This parser only supports u8, u16, u32 and u64 integers.



ObjectNotSupported(u8)

The binary property list has an unsupported object type.



UnexpectedXmlEof

The XML property list encountered an early end of the document.



UnexpectedXmlEvent(XmlEvent)

The XML property list contains an unexpected XML event.



XmlObjectNotSupported(String)

The XML property list contains an unsupported object type.



XmlError(Error)

The XML property list contains invalid XML.



IoError(Error)

The reader experienced an I/O error.



IntError(ParseIntError)

The XML property list contains an invalid integer value



FloatError(ParseFloatError)

The XML property list contains an invalid float value



DateError(ParseError)

The XML property list contains an invalid date value



Base64Error(FromBase64Error)

The XML property list contains an invalid data value



Utf8Error(Utf8Error)

The property list contains an invalid UTF-8 string value



Utf16Error(FromUtf16Error)

The property list contains an invalid UTF-16 string value